Co je OiRA? | OiRA

Témata

# Co je OiRA?

## Jste na platformě OiRA poprvé?

Zde je krátký úvod k hodnocení rizik s informacemi o tom, jak vám může OiRA pomoci toto hodnocení zvládnout.

## Co je hodnocení rizik?

Hodnocení rizik tvoří základ úspěšného řízení bezpečnosti a ochrany zdraví a má zásadní význam pro snížení počtu pracovních úrazů a nemocí z povolání. Je-li náležitě provedeno, může zlepšit bezpečnost a ochranu zdraví na pracovišti a výkonnost podniků obecně.

Bezpečnost a ochrana zdraví pracovníků je v Evropě zajištěna prostřednictvím hodnocení a řízení rizik při práci. Zaměstnavatelé mají zákonnou povinnost zajistit bezpečnost a ochranu zdraví pracovníků ve všech aspektech souvisejících s prací a provádět hodnocení rizik. Každá společnost proto musí provést hodnocení rizik a vypracovat akční plán. Aby bylo možné provádět účinné hodnocení rizik na pracovišti, potřebují všichni zúčastnění jasnou představu o:

- právním rámci a příslušných pojmech,
- postupu používaném při hodnocení rizik,
- úloze, kterou mají hrát hlavní aktéři zapojení do tohoto procesu.

Pracovníci a/nebo jejich zástupci mají právo být konzultováni ohledně opatření pro provádění hodnocení rizik a účast na něm.

Více informací o hodnocení rizik a zapojení pracovníků a/nebo jejich zástupců do procesu hodnocení rizik je uvedeno na internetových stránkách projektu OiRA.

## Co je OiRA?

OiRA je zkratka pro Online Interactive Risk Assessment (on-line interaktivní hodnocení rizik). Jedná se o internetovou aplikaci, která vám umožňuje provádět hodnocení bezpečnostních a zdravotních rizik na vašem pracovišti.

## Pro koho je platforma OiRA určena?

Platformu OiRA může použít kdokoli k posouzení bezpečnostních a zdravotních rizik, která mohou na pracovišti existovat.

OiRA je však koncipována tak, aby měla největší přínos pro menší podniky. OiRA byla vyvinuta speciálně s cílem podpořit tyto podniky při posuzování rizik na pracovišti a pomoci jim vypracovat zdokumentované hodnocení rizik, včetně akčního plánu přizpůsobeného požadavkům podniku.

## Co musím udělat?

V rámci procesu hodnocení rizik pomocí nástroje OiRA je třeba provést několik kroků:

- Příprava: některé nástroje mají profilové otázky, které vám pomohou přizpůsobit nástroj specifikům vaší provozovny. Pokud odpovíte na profilové otázky, nástroj se přizpůsobí vaší konkrétní situaci a zobrazí vám příslušné moduly.

- Zapojení: každé hodnocení rizik by mělo být provedeno s aktivním zapojením pracovníků. Nástroj vám umožňuje vytisknout celé znění hodnocení rizik, nebo jeho části, abyste mohli pracovníky informovat a získat zpětnou vazbu.

- Identifikace rizika: OiRA představí řadu možných bezpečnostních a zdravotních rizik nebo problémů, jež by se mohly na vašem pracovišti vyskytovat. Odpovíte-li na tvrzení/otázky buď ano, nebo ne, uvedete, zda taková nebezpečí nebo problémy existují. Můžete se také rozhodnout ponechat otázku nezodpovězenou a odložit její zodpovězení na později.

- Vyhodnocení: některé nástroje vás požádají, abyste určili prioritu zjištěných rizik. To lze provést různými způsoby, což závisí na rozhodnutích našich národních partnerů/vývojářů nástrojů OiRA a na jejich konkrétním přístupu. Některé nástroje stanoví prioritu rizik také automaticky v pozadí, přičemž tyto priority můžete zrušit.

- Akční plán: u každého zjištěného rizika vás nástroj požádá, abyste rozhodli o jednom či více opatřeních k jeho odstranění nebo snížení. Většina nástrojů vám navrhne určitá opatření. Vždy se také můžete rozhodnout, zda zadáte vlastní opatření.

- Zpráva: máte zákonnou povinnost své hodnocení rizik zdokumentovat. V sekci „Zpráva“ naleznete řadu zpráv, jež vám pomohou dohlížet na hodnocení rizik a sledovat kroky/opatření, jež jste se rozhodli provést za účelem odstranění či zmírnění zjištěných rizik.

## Jak dlouho to bude trvat?

Nelze říci, jak dlouho bude hodnocení obvykle trvat, neboť nástroje se liší podle odvětví a země.

Hodnocení však můžete věnovat jakoukoli dobu, kterou máte k dispozici, a poté se k němu vrátit, jak vám to bude vyhovovat, a pokračovat od stejného bodu, kde jste skončili.

## Proč se musím zaregistrovat?

Při zahájení prvního hodnocení rizik budete nejdříve vyzváni, abyste vytvořili účet OiRA - jedná se o jednoduchý a rychlý proces.

Registrace vám umožňuje se kdykoli přihlásit a pokračovat v předchozích hodnoceních nebo začít s novými.

Jste-li registrovaným uživatelem, máte rovněž možnost kdykoli získat tištěné, přesné a aktualizované hodnocení rizik.

## Je třeba se připravit?

K používání nástroje není zapotřebí žádná zvláštní příprava, měli byste si však udělat čas a zamyslet nad tím, kdo bude hodnocení rizik provádět a jak budou do tohoto procesu zapojeni pracovníci.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More